/*
Copyright © 2024 filifa

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"fmt"
	"log"
	"strconv"

	"github.com/spf13/cobra"
	"scm.dairydemon.net/filifa/mlblive/cmd/internal/statsapi"
)

var date string
var team teamFlag
var sport sportFlag

func schedule(cmd *cobra.Command, args []string) {
	var teamId string
	if team == "" {
		teamId = string(team)
	} else {
		teamId = strconv.Itoa(int(teamIDs[string(team)]))
	}

	var sportId string
	if sport == "" {
		sportId = strconv.Itoa(int(statsapi.MLB))
	} else {
		sportId = strconv.Itoa(int(sportIDs[string(sport)]))
	}

	sched, err := statsapi.RequestSchedule(sportId, teamId, date)
	if err != nil {
		log.Fatal(err)
	}

	fmt.Println(string(sched))
}

// scheduleCmd represents the schedule command
var scheduleCmd = &cobra.Command{
	Use:   "schedule",
	Short: "Fetch daily schedules",
	Long:  `Fetch a day's schedule for the whole league or a specific team.`,
	Args:  cobra.NoArgs,
	Run:   schedule,
}

func init() {
	rootCmd.AddCommand(scheduleCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// scheduleCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	scheduleCmd.Flags().VarP(&team, "team", "t", "team to get schedule for")
	scheduleCmd.Flags().StringVarP(&date, "date", "d", "", "date to get schedule for (YYYY-MM-DD)")
	scheduleCmd.Flags().VarP(&sport, "sport", "s", "sport to get schedule for")
}
